==> blue_gan-4.46.1.tar.gz: blue_gan-4.46.1/README.md <==
# 🖌️ blue-gan

🖌️ `@gan` is a command interface for [PyTorch-GAN](https://github.com/eriklindernoren/PyTorch-GAN).

```bash
pip install blue-gan
```

|   |   |
| --- | --- |
| [`stylegan2-pytorch`](./blue_gan/docs/stylegan2_pytorch.md) [![image](https://raw.githubusercontent.com/lucidrains/stylegan2-pytorch/master/samples/cities.jpg)](./blue_gan/docs/stylegan2_pytorch.md) Simple StyleGan2 for Pytorch 🔥 |  |
| [`PyTorch-GAN`](./blue_gan/docs/PyTorch_GAN.md) [![image](https://github.com/eriklindernoren/PyTorch-GAN/raw/master/assets/logo.png)](./blue_gan/docs/PyTorch_GAN.md) 6+ years old, missing assets, bugs. 🛑 | [`What is a GAN?`](https://aws.amazon.com/what-is/gan/) [![image](https://d2908q01vomqb2.cloudfront.net/f1f836cb4ea6efb2a0b1b99f41ad8b103eff4b59/2021/11/11/ML-6149-image025.jpg)](https://aws.amazon.com/what-is/gan/) Background review. |

---


[![pylint](https://github.com/kamangir/blue-gan/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-gan/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-gan/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-gan/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-gan/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-gan/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-gan.svg)](https://pypi.org/project/blue-gan/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-gan)](https://pypistats.org/packages/blue-gan)

built by 🌀 [`blue_options-4.234.1`](https://github.com/kamangir/awesome-bash-cli), based on 🖌️ [`blue_gan-4.46.1`](https://github.com/kamangir/blue-gan).

==> blue_gan-4.47.1.tar.gz: blue_gan-4.47.1/README.md <==
# 🖌️ blue-gan

🖌️ `@gan` is a command interface for [PyTorch-GAN](https://github.com/eriklindernoren/PyTorch-GAN).

```bash
pip install blue-gan
```

|   |   |
| --- | --- |
| [`stylegan2-pytorch`](./blue_gan/docs/stylegan2_pytorch.md) [![image](https://raw.githubusercontent.com/lucidrains/stylegan2-pytorch/master/samples/cities.jpg)](./blue_gan/docs/stylegan2_pytorch.md) Simple StyleGan2 for Pytorch. ⏸️ |  |
| [`PyTorch-GAN`](./blue_gan/docs/PyTorch_GAN.md) [![image](https://github.com/eriklindernoren/PyTorch-GAN/raw/master/assets/logo.png)](./blue_gan/docs/PyTorch_GAN.md) 6+ years old, missing assets, bugs. 🛑 | [`What is a GAN?`](https://aws.amazon.com/what-is/gan/) [![image](https://d2908q01vomqb2.cloudfront.net/f1f836cb4ea6efb2a0b1b99f41ad8b103eff4b59/2021/11/11/ML-6149-image025.jpg)](https://aws.amazon.com/what-is/gan/) Background review. |

---


[![pylint](https://github.com/kamangir/blue-gan/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-gan/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-gan/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-gan/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-gan/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-gan/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-gan.svg)](https://pypi.org/project/blue-gan/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-gan)](https://pypistats.org/packages/blue-gan)

built by 🌀 [`blue_options-4.234.1`](https://github.com/kamangir/awesome-bash-cli), based on 🖌️ [`blue_gan-4.47.1`](https://github.com/kamangir/blue-gan).
